# Public APIs

A collective list of JSON APIs for use in web development.

For information on contributing to this project, please see the [contributing guide](CONTRIBUTING.md).

## Index

* [Animals](#animals)
* [Anime](#anime)
* [Anti-Malware](#anti-malware)
* [Art & Design](#art--design)
* [Books](#books)
* [Business](#business)
* [Calendar](#calendar)
* [Cloud Storage & File Sharing](#cloud-storage--file-sharing)
* [Currency Exchange](#currency-exchange)
* [Development](#development)
* [Documents & Productivity](#documents--productivity)
* [Data Access](#data-access)
* [Data Validation](#data-validation)
* [Environment](#environment)
* [Food and Drink](#food-and-drink)
* [Games & Comics](#games--comics)
* [Geocoding](#geocoding)
* [Health](#health)
* [Machine Learning](#machine-learning)
* [Music](#music)
* [News](#news)
* [Open Source projects](#open-source-projects)
* [Personality](#personality)
* [Photography](#photography)
* [Science](#science)
* [Security](#security)
* [Shopping](#shopping)
* [Social](#social)
* [Sports/Fitness](#sportsfitness)
* [Transportation](#transportation)
* [University](#university)
* [Vehicle](#vehicle)
* [Video](#video)
* [Weather](#weather)

### Animals

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| IUCN | IUCN Red List of Threatened Species | `token` | No | [Go!](http://apiv3.iucnredlist.org/api/v3/docs) |
| Petfinder | Adoption | No | Yes | [Go!](https://www.petfinder.com/developers/api-docs/) |
| RescueGroups | Adoption | No | Yes | [Go!](https://userguide.rescuegroups.org/display/APIDG/API+Developers+Guide+Home) |

### Anime

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| AniList | AniList Anime | `oAuth` | No | [Go!](http://anilist-api.readthedocs.org/en/latest/#) |
| Kitsu | Kitsu Anime | `oAuth` | No | [Go!](http://docs.kitsu17.apiary.io/) |

### Anti-Malware

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Certly | Certly Link/Domain Flagging | `token` | Yes | [Go!](https://guard.certly.io/) |
| Google Safe Browsing | Google Link/Domain Flagging | `token` | Yes | [Go!](https://developers.google.com/safe-browsing/) |
| Metacert | Metacert Link Flagging | `token` | Yes | [Go!](https://metacert.com/) |
| VirusTotal | VirusTotal File/URL Analysis | `token` | Yes | [Go!](https://www.virustotal.com/en/documentation/public-api/) |
| Web Of Trust (WOT) | Website reputation | `key` string | Yes | [Go!](https://www.mywot.com/wiki/API) |

### Art & Design

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Dribbble | Design | `oAuth` | No | [Go!](http://developer.dribbble.com/v1/) |
| Noun Project | Icons | `oAuth` | No | [Go!](http://api.thenounproject.com/index.html) |
| Rijksmuseum| Art | No | Yes | [Go!](https://www.rijksmuseum.nl/en/api) |

### Books

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| British National Bibliography | Books | No | No | [Go!](http://bnb.data.bl.uk/) |
| Good Reads | Books | No | Yes | [Go!](https://www.goodreads.com/api) |
| Google Books | Books | `oAuth` | Yes | [Go!](https://developers.google.com/books/) |

### Business

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| mailgun | Email Service | `apiKey` query string | No | [Go!](http://www.mailgun.com/) |
| markerapi | Trademark Search | No | No | [Go!](http://www.markerapi.com/) |

### Calendar

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Church Calendar | Catholic liturgical calendar | No | No | [Go!](http://calapi.inadiutorium.cz/) |
| Date and Time | Global Date and Time | No | No | [Go!](http://www.timeanddate.com/services/api/) |
| Holidays | Free API for obtaining information about holidays. | No | No | [Go!](http://holidayapi.com/) |
| Non-Working Days | Database of ICS files for non working days | No | Yes | [Go!](https://github.com/gadael/icsdb) |

### Cloud Storage & File Sharing

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Box | File Sharing and Storage | `oAuth` | Yes | [Go!](https://developer.box.com/) |
| Dropbox | File Sharing and Storage | `oAuth` | Yes | [Go!](https://www.dropbox.com/developers) |
| Google Drive | File Sharing and Storage | `oAuth` | Yes | [Go!](https://developers.google.com/drive/) |
| OneDrive | File Sharing and Storage | `oAuth` | Yes | [Go!](https://dev.onedrive.com/) |

### Currency Exchange

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Currencylayer | Exchange rates and currency conversion | `apiKey` query string | Yes | [Go!](https://currencylayer.com/documentation) |
| Fixer.io | Exchange rates and currency conversion | No | No | [Go!](http://fixer.io) |

### Development

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Adorable Avatars | Generate random cartoon avatars | No | No | [Go!](http://avatars.adorable.io) |
| APIs.guru | Wikipedia for Web APIs, OpenAPI/Swagger specs for public APIs | No | Yes | [Go!](https://apis.guru/api-doc/) |
| CDNJS | Library info on CDNJS | No | Yes | [Go!](https://api.cdnjs.com/libraries/jquery) |
| Faceplusplus | A tool to detect face | `oAuth` | No | [Go!](http://www.faceplusplus.com/uc_home/) |
| Github - User Data | Pull public information for a user's github | No | Yes | [Go!](https://api.github.com/users/hackeryou) |
| Gitter | Chat for GitHub | `oAuth` | Yes | [Go!](https://developer.gitter.im/docs/) |
| Hipster Ipsum | Generates Hipster Ipsum text | No | No | [Go!](http://hipsterjesus.com/) |
| JSONPlaceholder | Fake data for testing and prototyping | No | No | [Go!](http://jsonplaceholder.typicode.com/) |
| LiveCoding | Live Coding Streaming | `oAuth` | Yes | [Go!](https://www.livecoding.tv/developer/applications/) |
| Lorem Text | Generates Lorem Ipsum text | `X-Mashape-Key` as header | Yes | [Go!](https://market.mashape.com/montanaflynn/lorem-text-generator) |
| Loripsum | The "lorem ipsum" generator that doesn't suck | No | No | [Go!](http://loripsum.net/) |
| Myjson | A simple JSON store for your web or mobile app | No | No | [Go!](http://myjson.com/api) |
| Plino | Spam filtering system | No | Yes | [Go!](https://plino.herokuapp.com/) |
| Random Word | Generate random word | No | No | [Go!](http://randomword.setgetgo.com/) |
| RandomUser | Generates random user data | No | Yes | [Go!](https://randomuser.me) |
| ReqRes | A hosted REST-API ready to respond to your AJAX requests | No | No | [Go!](http://reqres.in/) |
| RoboHash | Generate random robot/alien avatars | No | Yes | [Go!](https://robohash.org/) |
| StackExchange | Q&A forum for developers | `oAuth` | Yes | [Go!](https://api.stackexchange.com/) |
| Stormpath | User Authentication | `apiKey` | Yes | [Go!](https://stormpath.com/) |
| UI Faces | Find and generate sample avatars for user interfaces | No | No | [Go!](http://uifaces.com/api) |
| UI Names | Generate random fake names | No | Yes | [Go!](https://github.com/thm/uinames) |

### Documents & Productivity

| API | Description | OAuth |Link |
|---|---|---|---|---|
| File.io | Files | No | Yes | [Go!](https://file.io) |
| pdflayer API | HTML/URL to PDF | No | Yes | [Go!](https://pdflayer.com) |
| Wunderlist | Todo Lists | `oAuth` | Yes | [Go!](https://developer.wunderlist.com/documentation) |

### Data Access

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| 18F | US Federal Government /Developer Program | No | No | [Go!](http://18f.github.io/API-All-the-X/) |
| Abbreviation | Get abbreviations and meanings | `X-Mashape-Key` as header | Yes | [Go!](https://market.mashape.com/daxeel/abbreviations) |
| Callook.info | United States ham radio callsigns | No | Yes | [Go!](https://callook.info) |
| Celebinfo | Celebrity information | `X-Mashape-Key` as header | Yes | [Go!](https://market.mashape.com/daxeel/celebinfo/) |
| Colorado Data Engine | Formatted and geolocated Colorado public data | No | Yes | [Go!](http://codataengine.org/) |
| Colorado Information Marketplace | Colorado State Government Open Data | No | Yes | [Go!](https://data.colorado.gov/) |
| Data USA | US Public Data | No | No | [Go!](http://datausa.io/about/api/) |
| Dronestream | Tracks United States drone strikes | No | No | [Go!](http://dronestre.am/) |
| fonoApi | Mobile Device Description | No | Yes | [Go!](https://fonoapi.freshpixl.com/) |
| Open Government, Australia | Australian Government Open Data | No | Yes | [Go!](https://www.data.gov.au/) |
| Open Government, USA | United States Government Open Data | No | Yes | [Go!](https://www.data.gov/) |
| Open Government, Canada | Canadian Government Open Data | No | No | [Go!](http://open.canada.ca/en) |
| Open Government Data, India | Indian Government Open Data | `token` | Yes | [Go!](https://data.gov.in/) |
| Pearson | Dictionary Data | `apiKey` query string | No | [Go!](http://developer.pearson.com/apis/dictionaries) |
| Quandl | Stock Market Data | No | Yes | [Go!](https://www.quandl.com/) |
| Scoop.it | Content Curation Service | `apiKey` query string | Yes | [Go!](https://www.scoop.it/dev) |
| Wikipedia | Mediawiki Encyclopedia | No | Yes | [Go!](https://www.mediawiki.org/wiki/API:Main_page) |
| Wordnik | Dictionary Data | No | No | [Go!](http://developer.wordnik.com) |
| Yelp | Find Local Business | `oAuth` | Yes | [Go!](https://www.yelp.com/developers) |

### Data Validation

| API | Description | OAuth |Link |
|---|---|---|---|---|
| languagelayer | Language detection | No | Yes | [Go!](https://languagelayer.com) |
| mailboxlayer | Email address validation | No | Yes | [Go!](https://mailboxlayer.com) |
| numverify | Phone number validation | No | Yes | [Go!](https://numverify.com) |
| vatlayer | VAT number validation | No | Yes | [Go!](https://vatlayer.com) |

### Environment

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| PM2.5.in | PM2.5 Data of China | `apiKey` query string | No | [Go!](http://www.pm25.in/api_doc) |

### Food and Drink

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| BigOven | Recipe Search | `X-Mashape-Key` as header | No | [Go!](http://api2.bigoven.com/) |
| BreweryDB | Beer | `apiKey` query string | No | [Go!](http://www.brewerydb.com/developers) |
| Edamam | Recipe Search | `apiKey` query string | Yes | [Go!](https://developer.edamam.com/) |
| Food2Fork | Recipe Search | `apiKey` query string | No | [Go!](http://food2fork.com/about/api) |
| LCBO | Alcohol | `apiKey` query string | Yes | [Go!](https://lcboapi.com/) |
| PunkAPI | Brewdog Beer Recipes | No | Yes | [Go!](https://punkapi.com/) |
| Recipe Puppy | Food | No | No | [Go!](http://www.recipepuppy.com/about/api/) |
| Yummly | Find food recipes | No | Yes | [Go!](https://developer.yummly.com/) |

### Games & Comics

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Battle.net | Blizzard Entertainment | No | Yes | [Go!](https://dev.battle.net/)  |
| Chuck Norris Database | Jokes | No | No | [Go!](http://www.icndb.com/api) |
| Clash of Clans | Clash of Clans Game Information | No | Yes | [Go!](https://developer.clashofclans.com) |
| Clash Royale | Clash Royale Game Information | No | Yes | [Go!](https://github.com/martincarrera/clash-royale-api)  |
| Comic Vine | Comics | No | No | [Go!](http://comicvine.gamespot.com/api/documentation) |
| Deck of Cards | Deck of Cards | No | No | [Go!](http://deckofcardsapi.com/)  |
| Eve Online | Third-Party Developer Documentation | `oAuth` required for some parts | Yes | [Go!](https://eveonline-third-party-documentation.readthedocs.io/en/latest/) |
| Giant Bomb | Video Games | No | [Go!](http://www.giantbomb.com/api/documentation) |
| Guild Wars 2 | Guild Wars 2 Game Information | `apiKey` query string (for some routes) | Yes | [Go!](https://wiki.guildwars2.com/wiki/API:Main) |
| Magic The Gathering | Magic The Gathering Game Information | No | No | [Go!](http://magicthegathering.io/) |
| Marvel | Marvel Comics | No | No | [Go!](http://developer.marvel.com) |
| Minecraft | Minecraft server info & user info) | No | Yes | [Go!](https://mcapi.ca/) |
| Open Trivia | Trivia Questions | No | Yes | [Go!](https://opentdb.com/api_config.php) |
| Pokéapi | Pokémon Information | No | No | [Go!](http://pokeapi.co) |
| Riot Games | League of Legends Game Information | `apiKey` | Yes | [Go!](https://developer.riotgames.com/) |
| Steam | Steam Client Interaction | `oAuth` | Yes | [Go!](https://developer.valvesoftware.com/wiki/Steam_Web_API) |
| SWAPI | Star Wars Information | No | Yes | [Go!](https://swapi.co) |

### Geocoding

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| GeoNames | Place names and other geographical data | No | No | [Go!](http://www.geonames.org/export/web-services.html) |
| GéoApi | French geographical data | No | Yes | [Go!](https://api.gouv.fr/api/geoapi.html) |
| Google Maps | Create/customize digital maps based on Google Maps data | `apiKey` query string | Yes | [Go!](https://developers.google.com/maps/) |
| IP 2 Country | Map an IP to a country | No | Yes | [Go!](https://ip2country.info) |
| IP Address Details| Find geolocation with ip address | No | Yes | [Go!](https://ipinfo.io/) |
| Mapbox | Create/customize beautiful digital maps | `apiKey` query string | Yes | [Go!](https://www.mapbox.com/developers/) |
| Mapzen Search | Open Source & Open Data Global Geocoding Service | No | Yes | [Go!](https://mapzen.com/projects/search) |
| Mexico | Mexico RESTful zip codes API | No | Yes | [Go!](https://github.com/IcaliaLabs/sepomex) |
| OpenCage | Forward and reverse geocoding using open data | No | Yes | [Go!](https://geocoder.opencagedata.com) |
| OpenStreetMap | Navigation, geolocation and geographical data | `oAuth` | No | [Go!](http://wiki.openstreetmap.org/wiki/API) |
| PostcodeData.nl | Provide geolocation data based on postcode for Dutch addresses | No | No | [Go!](http://api.postcodedata.nl/v1/postcode/?postcode=1211EP&streetnumber=60&ref=domeinnaam.nl&type=json) |
| Postcodes.io | Postcode lookup & Geolocation for the UK | No | Yes | [Go!](https://postcodes.io) |

### Health

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Diabetes | Logging and retrieving diabetes information | No | No | [Go!](http://predictbgl.com/api) |
| Flutrack | Influenza-like symptoms with geotracking | No | No | [Go!](http://www.flutrack.org/) |
| Makeup | Makeup Information | No | No | [Go!](http://makeup-api.herokuapp.com/) |
| Nutritionix | Worlds largest verified nutrition database | `apiKey` query string | Yes | [Go!](https://developer.nutritionix.com/) |
| USDA Nutrients | National Nutrient Database for Standard Reference | No | Yes | [Go!](https://ndb.nal.usda.gov/ndb/doc/index) |

### Machine Learning

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Clarifai | Computer Vision | `oAuth` | Yes | [Go!](https://predictbgl.com/api) |
| Wit.ai | Natural Language Processing | `oAuth` | Yes | [Go!](https://wit.ai/) |

### Music

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Deezer | Music | `oAuth` | No | [Go!](http://developers.deezer.com/api) |
| Discogs | Music | `oAuth` | Yes | [Go!](https://www.discogs.com/developers/) |
| EchoNest | Music | No | No | [Go!](http://developer.echonest.com/docs/v4) |
| Genius | Crowdsourced lyrics and music knowledge | `oAuth` | Yes | [Go!](https://docs.genius.com/) |
| Jamendo | Music | `oAuth` | Yes | [Go!](https://developer.jamendo.com/v3.0) |
| iTunes Search | Software products | No | Yes | [Go!](https://affiliate.itunes.apple.com/resources/documentation/itunes-store-web-service-search-api/) |
| LastFm | Music | No | No | [Go!](http://www.last.fm/api) |
| Mixcloud | Music | No | Yes | [Go!](https://www.mixcloud.com/developers/) |
| MusicBrainz | Music | No | Yes | [Go!](https://musicbrainz.org/doc/Development/XML_Web_Service/Version_2) |
| Musikki | Music | No | Yes | [Go!](https://music-api.musikki.com/reference) |
| Musixmatch | Music | `apikey` query string | Yes | [Go!](https://developer.musixmatch.com/) |
| Songsterr | Provides guitar, bass and drums tabs and chords  | No | Yes | [Go!](https://www.songsterr.com/a/wa/api/) |
| Soundcloud | Music | No | Yes | [Go!](https://developers.soundcloud.com/) |
| Spotify | Music | `oAuth` required for some parts | Yes | [Go!](https://developer.spotify.com/web-api/) |
| Vagalume | Crowdsourced lyrics and music knowledge | `apikey` query string | Yes | [Go!](https://api.vagalume.com.br/docs/) |

### News

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| New York Times | Provides news | No, but `apikey` is required | Yes | [Go!](https://developer.nytimes.com/) |

### Open Source projects

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Countly  | Countly web analytics | No | No | [Go!](http://resources.count.ly/) |
| Drupal.org | Drupal.org | No | Yes | [Go!](https://www.drupal.org/drupalorg/api) |
| Libraries.io | Open source software libraries | `apiKey` query string | Yes | [Go!](https://libraries.io/api) |

### Personality

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Forismatic | Inspirational Quotes | No | No | [Go!](http://forismatic.com/en/api/) |
| Medium | Community of readers and writers offering unique perspectives on ideas. | `oAuth` | Yes | [Go!](https://github.com/Medium/medium-api-docs) |
| Quotes on Design | Inspirational Quotes | No | Yes | [Go!](https://quotesondesign.com/api-v4-0/) |
| Traitify | Assess, collect, and analyze Personality | No | Yes | [Go!](https://developer.traitify.com/) |

### Photography

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| 500px |  Photography Community | `oAuth` | Yes | [Go!](https://github.com/500px/api-documentation) |
| Flickr | Flickr Services | `oAuth` | Yes | [Go!](https://www.flickr.com/services/api/) |
| Gfycat | Jiffier GIFs | `oAuth` | Yes | [Go!](https://developers.gfycat.com/api/) |
| Giphy | Get all your gifs | No | Yes | [Go!](https://github.com/Giphy/GiphyAPI) |
| Imgur | Images | `oAuth` | Yes | [Go!](https://api.imgur.com/#overview) |
| ScreenShotLayer | URL 2 Image | No | Yes | [Go!](https://screenshotlayer.com) |
| Unsplash | Photography | `oAuth` | Yes | [Go!](https://unsplash.com/developers) |

### Science

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Fedger.io | Query machine intelligence data | No | Yes | [Go!](https://dev.fedger.io/docs/) |
| inspirehep.net | High Energy Physics info. system | No | Yes | [Go!](https://inspirehep.net/info/hep/api?ln=en) |
| Launch Library | Upcoming Space Launches | No | Yes | [Go!](https://launchlibrary.net/1.2/docs/api.html) |
| Minor Planet Center | Asterank.com Information | No | No | [Go!](http://www.asterank.com/mpc) |
| NASA | NASA data, including imagery | No | Yes | [Go!](https://api.nasa.gov) |
| Open Notify | ISS astronauts, current location, etc | No | No | [Go!](http://open-notify.org/Open-Notify-API/) |
| Sunrise and Sunset | Sunset and sunrise times for a given latitude and longitude. | No | No | [Go!](http://sunrise-sunset.org/api) |
| USGS Earthquake Hazards Program | Earthquakes data real-time | No | No | [Go!](http://earthquake.usgs.gov/fdsnws/event/1/) |
| World Bank | World Data | No | No | [Go!](http://data.worldbank.org/developers) |

### Security

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| AXFR Database | AXFR public database | No | [Go!](http://api.axfrcheck.com) |
| UK Police | UK Police data | No | Yes | [Go!](https://data.police.uk/docs/) |

### Shopping

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| eBay | Sell and Buy on eBay | Yes | [Go!](https://go.developer.ebay.com/) |

### Social

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Discord bot | Make bots for Discord | `oAuth` | Yes | [Go!](https://discordapp.com/developers/docs/intro) |
| Facebook API | Facebook Login, Share on FB, Social Plugins, Analytics and more | `oAuth` | Yes | [Go!](https://developers.facebook.com/) |
| Foursquare | Interact with Foursquare users and places (geolocation-based checkins, photos, tips, events, etc) | `oAuth` | Yes | [Go!](https://developer.foursquare.com/) |
| Fuck Off as a Service | Asks someone to fuck off | No | Yes | [Go!](https://www.foaas.com) |
| Full Contact | Get Social Media profiles and contact Information | `oAuth` | Yes | [Go!](https://www.fullcontact.com/developer/docs/) |
| HackerNews | Social news for CS and entrepreneurship | No | Yes | [Go!](https://github.com/HackerNews/API) |
| Instagram | Instagram Login, Share on Instagram, Social Plugins and more | `oAuth` | Yes | [Go!](https://www.instagram.com/developer/) |
| LinkedIn | The foundation of all digital integrations with LinkedIn | `oAuth` | Yes | [Go!](https://developer.linkedin.com/docs/rest-api) |
| Telegram MTProto | Read and write Telegram data | `oAuth` | Yes | [Go!](https://core.telegram.org/api#getting-started) |
| Telegram bot | Simplified HTTP version of the MTProto API for bots | `oAuth` | Yes | [Go!](https://core.telegram.org/bots/api) |
| Pinterest | The world's catalog of ideas | `oAuth` | Yes | [Go!](https://developers.pinterest.com/) |
| PWRTelegram bot | Boosted version of the Telegram bot API | `oAuth` | Yes | [Go!](https://pwrtelegram.xyz) |
| Reddit | Homepage of the internet | `oAuth` required for some parts | Yes | [Go!](https://www.reddit.com/dev/api) |
| Slack | Team Instant Messaging | `oAuth` | Yes | [Go!](https://api.slack.com/) |
| Tumblr | Read and write Tumblr Data | `oAuth` | Yes | [Go!](https://www.tumblr.com/docs/en/api/v2) |
| Twitch | Game Streaming API | `oAuth` | Yes | [Go!](https://github.com/justintv/Twitch-API) |
| Twitter | Read and write Twitter data | `oAuth` | Yes | [Go!](https://dev.twitter.com/rest/public) |
| vk API | Read and write vk dat | `oAuth` | Yes | [Go!](https://vk.com/dev/sites) |

### Sports/Fitness

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| City Bikes | City Bikes around the world | No | No | [Go!](http://api.citybik.es/v2/) |
| Ergast F1 | F1 data from the beginning of the world championships in 1950 | No | No | [Go!](http://ergast.com/mrd/) |
| FitBit | FitBit Information | No | Yes | [Go!](https://dev.fitbit.com) |
| Football-Data.org | Football Data | No | No | [Go!](http://api.football-data.org) |
| JCDecaux Bike | JCDecaux's self-service bicycles | `apiKey` query string | Yes | [Go!](https://developer.jcdecaux.com/) |
| Cricket Live Scores | live-score | `X-Mashape-Key` as header | Yes | [Go!](https://market.mashape.com/dev132/cricket-live-scores) |
| NFL Arrests | NFL Arrest Data | No | No | [Go!](http://nflarrest.com/api/) |
| Pro Motocross | The RESTful AMA Pro Motocross lap times for every racer on the start gate | No | No | [Go!](http://promotocrossapi.com) |
| Strava | Connect with athletes, activities and more | [`oAuth`](https://strava.github.io/api/v3/oauth/)| Yes | [Go!](https://strava.github.io/api/) |
| Wger | Workout manager data as exercises, muscles or equipments | `apiKey` query string | Yes | [Go!](https://wger.de/en/software/api) |

### Transportation

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Amadeus Travel Innovation Sandbox | Travel Search - Limited usage | `apikey` query string | Yes | [Go!](https://sandbox.amadeus.com/) |
| Community Transit | Transitland API | No | Yes | [Go!](https://github.com/transitland/transitland-datastore/blob/master/README.md#api-endpoints) |
| Goibibo | API for travel search  | `apiKey` query string | Yes | [Go!](https://developer.goibibo.com/docs) |
| Indian Railways | Indian Railways API | `token` | [Go!](http://api.erail.in/) |
| The Nomad List | A list of the best places to live/work remotely | No | Yes | [Go!](https://nomadlist.com/faq) |
| Schiphol Airport | Schiphol | `oAuth` | Yes | [Go!](https://flight-info.3scale.net/) |
| TransitLand | Transit Aggregation | No | Yes | [Go!](https://transit.land/documentation/datastore/api-endpoints.html) |
| Transport for Atlanta, US | Marta | No | No | [Go!](http://www.itsmarta.com/developers/data-sources/marta-bus-realtime-restful-api.aspx) |
| Transport for Belgium | Belgian transport API | No | Yes | [Go!](https://hello.irail.be/api/) |
| Transport for Boston, MA, USA | MBTA API | No | No | [Go!](http://realtime.mbta.com/Portal/Home/Documents) |
| Transport for Budapest | Budapest public transport API | No | No | [Go!](http://docs.bkkfutar.apiary.io/) |
| Transport for Chicago, US | CTA | No | No | [Go!](http://www.transitchicago.com/developers/) |
| Transport for Czech Republic | Czech transport API | No | No | [Go!](http://www.chaps.cz/eng/products/idos-internet) |
| Transport for Finland | Finnish transport API | No | No | [Go!](http://digitransit.fi/en/developers/) |
| Transport for Germany | Deutsche Bahn (DB) API | `authKey` query string | No | [Go!](http://data.deutschebahn.com/apis/fahrplan/) |
| Transport for Berlin | third-party VBB API | No | Yes | [Go!](https://github.com/derhuerst/vbb-rest/blob/master/docs/index.md) |
| Transport for India | India Public Transport API | Api key | Yes | [Go!](https://data.gov.in/sector/transport) |
| Transport for London, England | TfL API | No | Yes | [Go!](https://api.tfl.gov.uk) |
| Transport for Minneapolis, US | NexTrip API | `oAuth` | No | [Go!](http://svc.metrotransit.org/) |
| Transport for New York City | MTA | api key | No | [Go!](http://datamine.mta.info/) |
| Transport for Norway | Norwegian transport API | No | No | [Go!](http://reisapi.ruter.no/help) |
| Transport for Ottawa, Canada | OC Transpo next bus arrival API | No | No | [Go!](http://www.octranspo1.com/developers) |
| Transport for Paris, France | RATP Open Data API | No | No | [Go!](http://data.ratp.fr/api/v1/console/datasets/1.0/search/) |
| Transport for Philadelphia | SEPTA APIs | No | No | [Go!](http://www3.septa.org/hackathon/) |
| Transport for Rio de Janeiro, Brazil | Prefeitura do Rio (City Hall) | No | No | [Go!](http://data.rio/group/transporte-e-mobilidade) |
| Transport for Sweden | Public Transport consumer | `oAuth` | Yes | [Go!](https://www.trafiklab.se/api) |
| Transport for Switzerland | Swiss public transport API | No | Yes | [Go!](https://transport.opendata.ch/) |
| Transport for São Paulo, Brazil | SPTrans | `oAuth` | No | [Go!](http://www.sptrans.com.br/desenvolvedores/APIOlhoVivo/Documentacao.aspx) |
| Transport for The Netherlands | NS | No | No | [Go!](http://www.ns.nl/reisinformatie/ns-api) |
| Transport for Tokyo, Japan | Tokyo Metro | `apiKey` query string | Yes | [Go!](https://developer.tokyometroapp.jp/)  |
| Transport for Toronto, Canada | TTC | No | Yes | [Go!](https://myttc.ca/developers) |
| Transport for Vancouver, Canada | TransLink | `oAuth` | Yes | [Go!](https://developer.translink.ca/) |
| Transport for Washington, US | Washington Metro transport API | `oAuth` | Yes | [Go!](https://developer.wmata.com/) |
| Transport for Madrid, Spain | Madrid BUS transport API | `apiKey` query string | No | [Go!](http://opendata.emtmadrid.es/Servicios-web/BUS) |
| Transport for Auckland, New Zealand | Auckland Transport API  | No | Yes | [Go!](https://api.at.govt.nz/) |
| Uber | Request Uber rides, reach riders, transport things, and reward drivers | `oAuth` | Yes | [Go!](https://developer.uber.com/) |
| WhereIsMyTransport | Platform for public transport data in emerging cities  | `oAuth` | Yes | [Go!](https://developer.whereismytransport.com/) |

### University

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Universities List | University names, countries and domains| No | Yes | [Go!](https://github.com/Hipo/university-domains-list) |

### Vehicle

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Vehicles | Lot of vehicles informations | `apiKey` query string | No | [Go!](http://developer.edmunds.com/api-documentation/overview/) |

### Video

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| An API of Ice And Fire | Game Of Thrones API | No | Yes | [Go!](https://anapioficeandfire.com/) |
| Dailymotion | Dailymotion Developer API | `oAuth` required for some parts | Yes | [Go!](https://developer.dailymotion.com/) |
| MovieDB | Movie Data | `apiKey` | Yes | [Go!](https://www.themoviedb.org/documentation/api) |
| Netflix Roulette | Netflix database | No | No | [Go!](http://netflixroulette.net/api/) |
| OMDB | Open movie database | No | Yes | [Go!](https://omdbapi.com/) |
| Ron Swanson Quotes | Television | No | Yes | [Go!](https://github.com/jamesseanwright/ron-swanson-quotes#ron-swanson-quotes-api) |
| TVMaze | TV Show Data | No | No | [Go!](http://www.tvmaze.com/api) |
| Video download | Video download API for youtube, rai.it, mediaset.it, la7.it and hundreds of other sites. | No | Yes | [Go!](https://api.daniil.it) |
| Vimeo | Vimeo Developer API | `oAuth` | Yes | [Go!](https://developer.vimeo.com/) |
| YouTube | Add YouTube functionality to your sites and apps. | `oAuth` required for some parts | Yes | [Go!](https://developers.google.com/youtube/) |

### Weather

| API | Description | Auth | HTTPS | Link |
|---|---|---|---|---|
| Dark Sky | Weather | `apiKey` query string | Yes | [Go!](https://developer.forecast.io/) |
| OpenWeatherMap | Weather | `apiKey` query string | No | [Go!](http://openweathermap.org/api) |
| Wunderground | Weather | No | No | [Go!](http://www.wunderground.com/weather/api/) |
| Yahoo! Weather | Weather | No | Yes | [Go!](https://developer.yahoo.com/weather/) |
